<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Adventure_Travel
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head itemscope itemtype="http://schema.org/WebSite">
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>
<body <?php body_class(); ?> itemscope itemtype="http://schema.org/TravelAgency">
	<div id="page" class="site">
		<header id="masthead" class="site-header" itemscope itemtype="http://schema.org/WPHeader">
			<?php 	
			$ed_header 	= get_theme_mod( 'ed_header', true );
			if( $ed_header ){ ?>
				<div class="header-t" itemscope itemtype="http://schema.org/organization">
					<div class="container">
						<div class="header-left">
							<?php
							$phone 	= get_theme_mod( 'header_phone', __( '+0 0000000000', 'adventure-travel' ) );
							$email 	= get_theme_mod( 'header_email', __( 'info@example.com', 'adventure-travel' ) );
							if( $email ){ ?>
								<div class="header-block email">
									<a href="<?php echo esc_url( 'mailto:' . $email  ); ?>" itemprop="url">
										<i class="fas fa-envelope"></i>
										<span class="header-block-text" itemprop="email">
											<?php echo esc_html( $email ); ?>
										</span>
									</a>
								</div><?php 
							} 
							if( $phone ){ ?>
								<div class="header-block phone">
									<a href="<?php echo esc_url( 'tel:' . $phone ) ?>">
										<i class="fas fa-phone"></i>
										<span class="header-block-text" itemprop="telephone"><?php echo esc_html( $phone ); ?></span>
									</a>
								</div>
								<?php
							} ?>
						</div>
						<?php adventure_travel_social_icons( false ); ?>
					</div>
				</div> <!-- .header-t -->
				<?php 
			} ?>
			<div class="header-main">
				<div class="container">
					<div class="site-branding" itemscope itemtype="http://schema.org/organization">
						<div class="site-logo" itemprop="logo">
							<?php the_custom_logo(); ?>
						</div>
						<div class="site-title-wrap">
							<?php
							if ( is_front_page() ) :
								?>
								<h1 class="site-title" itemprop="name"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" itemprop="url"><?php bloginfo( 'name' ); ?></a></h1>
								<?php
							else :
								?>
								<p class="site-title" itemprop="name"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" itemprop="url" rel="home"><?php bloginfo( 'name' ); ?></a></p>
								<?php
							endif;
							$Adventure_Travel_description = get_bloginfo( 'description', 'display' );
							if ( $Adventure_Travel_description || is_customize_preview() ) :
								?>
								<p class="site-description" itemprop="description"><?php echo $Adventure_Travel_description; /* WPCS: xss ok. */ ?></p>
							<?php endif; ?>
						</div>
					</div><!-- .site-branding -->
					<nav id="site-navigation" class="main-navigation" itemscope itemtype="http://schema.org/SiteNavigationElement">
						<button class="toggle-button">
							<span class="toggle-bar"></span>
							<span class="toggle-bar"></span>
							<span class="toggle-bar"></span>
						</button>
						<?php
						wp_nav_menu( array(
							'theme_location' => 'primary',
							'menu_id'        => 'primary-menu',
							'fallback_cb'    => 'Adventure_Travel_primary_menu_fallback',
						) );
						?>
					</nav><!-- #site-navigation -->
				</div>
			</div>
		</header><!-- #masthead -->

		<?php
		/**
	     * Content
	     * 
	     * @hooked adventure_travel_content_start
	    */
	    do_action( 'adventure_travel_content' );