<?php
	/**
	* Functions which enhance the theme by hooking into WordPress
	*
	* @package Adventure_Travel
	*/

	/**
	* Adds custom classes to the array of body classes.
	*
	* @param array $classes Classes for the body element.
	* @return array
	*/
	if( ! function_exists( 'adventure_travel_body_classes' ) ) :
		function adventure_travel_body_classes( $classes ) {

			global $post;

			// Banner
			$ed_banner_section 	= get_theme_mod( 'ed_banner_section', 'static-banner' );
			if( !$ed_banner_section ){
				$classes[] = 'no-banner';
			}
			// Adds a class of hfeed to non-singular pages.
			if ( ! is_singular() ) {
				$classes[] = 'hfeed';
			}
			if( is_home() ){
				if( is_active_sidebar( 'right-sidebar' ) ){
					$classes[] = 'classic-layout rightsidebar';
				}else{
					$classes[] = 'classic-layout full-width';
				}
			}

			if( is_post_type_archive( 'trip' ) ){
		        $classes[] = 'grid-layout full-width';
		    }elseif( is_page() || is_singular( 'post')  ){				
				$sidebar_layout = get_post_meta( $post->ID, '_adventure_travel_sidebar_layout', true );
				if( $sidebar_layout == 'default-sidebar' ){
					if( is_active_sidebar( 'right-sidebar' ) ){
						$classes[] = 'rightsidebar';
					}else{
						$classes[] = 'full-width';
					}
				}elseif( $sidebar_layout == 'left-sidebar' ){
					if( is_active_sidebar( 'right-sidebar' ) ){
						$classes[] = 'leftsidebar';
					}else{
						$classes[] = 'full-width';
					}
				}elseif( $sidebar_layout == 'no-sidebar'  ){
					$classes[] = 'full-width';
				}else{
					$classes[] = 'rightsidebar';
				}
			}else{
				$classes[] = 'rightsidebar';
			}


			return $classes;
		}
	endif;
	add_filter( 'body_class', 'adventure_travel_body_classes' );

	/**
	* Add a pingback url auto-discovery header for single posts, pages, or attachments.
	*/
	if( ! function_exists( 'adventure_travel_pingback_header' ) ) :
		function adventure_travel_pingback_header() {
			if ( is_singular() && pings_open() ) {
				printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
			}
		}
	endif;
	add_action( 'wp_head', 'adventure_travel_pingback_header' );

	/**
	* Content Start
	* 
	*/
	if( ! function_exists( 'adventure_travel_content_start' ) ) :
		function adventure_travel_content_start(){
		    $home_sections = array( 'banner', 'why_choose', 'best_seller', 'popular_destination', 'stat_counter', 'popular_activities', 'featured_trip', 'testimonial', 'blog' );

		    $ed_section = adventure_travel_home_section();

		    if( is_front_page() && ! is_home() ){
		        if( !$ed_section ){ ?>
		        	<div id="content" class="site-content"><div class="container"> <?php
		        }
		    }else{ ?>
		        <div id="content" class="site-content">
		        <?php 
		        adventure_travel_header_banner(); ?>
	            <div class="container"> <?php
			}
		}
	endif;
	add_action( 'adventure_travel_content', 'adventure_travel_content_start' );